@@ -7,6 +7,7 @@
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
+#include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
 
@@ -46,6 +47,6 @@ int main () {
     wait (&status);
     assert (WIFEXITED (status) && WEXITSTATUS (status) == 0);
 
-    puts ("test-file => PASS!");
+    puts ("test_file => PASS!");
     return 0;
 }
